/*
Copyright (c) 2007-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: Server shut down file  
*/



/**
 @file
*/

#include "shutdownserver.h"

/**
	Wraps two phase construction.
*/
CDelayServerShutDown* CDelayServerShutDown::NewL()
	{
	CDelayServerShutDown* self = new(ELeave) CDelayServerShutDown;
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop();
	return self;
	}
/**
	Constructor
*/	
CDelayServerShutDown::CDelayServerShutDown()
: CActive(EPriorityStandard)
	{
	}

void CDelayServerShutDown::ConstructL()
	{
	User::LeaveIfError(iShutDownTimer.CreateLocal());
	CActiveScheduler::Add(this);
	}
/**
	Sets the time delay. 
	After this time interval if the number of connected clients stays at zero, the server will shut down.
*/	
void CDelayServerShutDown::SetDelay(TTimeIntervalMicroSeconds32 aDelay)
	{
	__ASSERT_ALWAYS(!IsActive(), User::Panic(_L("CDelayedShutDown"), 1));
	
	// Request another wait
	iShutDownTimer.After(iStatus, aDelay);
	SetActive();
	}
/**
	Destructor
*/	
CDelayServerShutDown::~CDelayServerShutDown()
	{
	Cancel();
	// Close timer
	iShutDownTimer.Close();
	}
/**
	Handles the active objects request completion event
*/
void CDelayServerShutDown::RunL()
	{
	// Stop the active scheduler
	CActiveScheduler::Stop();
	}
/**
	Cancels request	
*/	
void CDelayServerShutDown::DoCancel()
	{
	iShutDownTimer.Cancel();
	}


//EOF
